misc Package
============

:mod:`misc` Package
-------------------

.. automodule:: hyperspy.misc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`config_dir` Module
------------------------

.. automodule:: hyperspy.misc.config_dir
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dm3reader` Module
-----------------------

.. automodule:: hyperspy.misc.dm3reader
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fastica` Module
---------------------

.. automodule:: hyperspy.misc.fastica
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`image_utils` Module
-------------------------

.. automodule:: hyperspy.misc.image_utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`import_sklearn` Module
----------------------------

.. automodule:: hyperspy.misc.import_sklearn
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interactive_ns` Module
----------------------------

.. automodule:: hyperspy.misc.interactive_ns
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`natsort` Module
---------------------

.. automodule:: hyperspy.misc.natsort
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`physical_constants` Module
--------------------------------

.. automodule:: hyperspy.misc.physical_constants
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`progressbar` Module
-------------------------

.. automodule:: hyperspy.misc.progressbar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tifffile` Module
----------------------

.. automodule:: hyperspy.misc.tifffile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tv_denoise` Module
------------------------

.. automodule:: hyperspy.misc.tv_denoise
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: hyperspy.misc.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils_readfile` Module
----------------------------

.. automodule:: hyperspy.misc.utils_readfile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils_varia` Module
-------------------------

.. automodule:: hyperspy.misc.utils_varia
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xmlreader` Module
-----------------------

.. automodule:: hyperspy.misc.xmlreader
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    hyperspy.misc.eels
    hyperspy.misc.mpfit

